==> haskell-megaparsec7-7.0.5-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-megaparsec7.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 megaparsec
version:              7.0.5
visibility:           public
id:                   megaparsec-7.0.5-AprHGsrst533hYLYbxRam0
key:                  megaparsec-7.0.5-AprHGsrst533hYLYbxRam0
license:              BSD-2-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Megaparsec contributors,
    Paolo Martini <paolo@nemail.it>,
    Daan Leijen <daan@microsoft.com>

homepage:             https://github.com/mrkkrp/megaparsec
synopsis:             Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that strikes a nice balance between
    speed, flexibility, and quality of parse errors.

category:             Parsing
abi:                  e24806912e82ecea5da75d31d7882050
exposed:              True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Lexer
    Text.Megaparsec.Char Text.Megaparsec.Char.Lexer
    Text.Megaparsec.Debug Text.Megaparsec.Error
    Text.Megaparsec.Error.Builder Text.Megaparsec.Internal
    Text.Megaparsec.Pos Text.Megaparsec.Stream

hidden-modules:
    Text.Megaparsec.Class Text.Megaparsec.Common Text.Megaparsec.Lexer
    Text.Megaparsec.State

import-dirs:          /usr/lib/ghc-8.8.3/site-local/megaparsec-7.0.5
library-dirs:         /usr/lib/ghc-8.8.3/site-local/megaparsec-7.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/megaparsec-7.0.5
hs-libraries:         HSmegaparsec-7.0.5-AprHGsrst533hYLYbxRam0
depends:
    base-4.13.0.0 bytestring-0.10.10.0
    case-insensitive-1.2.1.0-CFENYIsBzRdLtvm9TEyykN containers-0.6.2.1
    deepseq-1.4.4.0 mtl-2.2.2
    parser-combinators-1.2.1-IRMw0PVyjClCzP4SjVbI21
    scientific-0.3.6.2-6irdu2VdjjMJDmbJHneA4J text-1.2.4.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-megaparsec7/html/megaparsec.haddock
haddock-html:         /usr/share/doc/haskell-megaparsec7/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-megaparsec7-7.0.5-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-megaparsec7.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 megaparsec
version:              7.0.5
visibility:           public
id:                   megaparsec-7.0.5-5RQOobVESbRHZgommtTFxx
key:                  megaparsec-7.0.5-5RQOobVESbRHZgommtTFxx
license:              BSD-2-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Megaparsec contributors,
    Paolo Martini <paolo@nemail.it>,
    Daan Leijen <daan@microsoft.com>

homepage:             https://github.com/mrkkrp/megaparsec
synopsis:             Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that strikes a nice balance between
    speed, flexibility, and quality of parse errors.

category:             Parsing
abi:                  9c99586d22c932b9e3aacbabbcb5c1a7
exposed:              True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Lexer
    Text.Megaparsec.Char Text.Megaparsec.Char.Lexer
    Text.Megaparsec.Debug Text.Megaparsec.Error
    Text.Megaparsec.Error.Builder Text.Megaparsec.Internal
    Text.Megaparsec.Pos Text.Megaparsec.Stream

hidden-modules:
    Text.Megaparsec.Class Text.Megaparsec.Common Text.Megaparsec.Lexer
    Text.Megaparsec.State

import-dirs:          /usr/lib/ghc-8.8.3/site-local/megaparsec-7.0.5
library-dirs:         /usr/lib/ghc-8.8.3/site-local/megaparsec-7.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/megaparsec-7.0.5
hs-libraries:         HSmegaparsec-7.0.5-5RQOobVESbRHZgommtTFxx
depends:
    base-4.13.0.0 bytestring-0.10.10.0
    case-insensitive-1.2.1.0-6XBMjp9a9YoKw1YO1CVyBh containers-0.6.2.1
    deepseq-1.4.4.0 mtl-2.2.2
    parser-combinators-1.2.1-IRMw0PVyjClCzP4SjVbI21
    scientific-0.3.6.2-HwSise45C5vHNs50sfVp6t text-1.2.4.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-megaparsec7/html/megaparsec.haddock
haddock-html:         /usr/share/doc/haskell-megaparsec7/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
